pub(crate) enum CoseAlgorithmPolicy {
RequireProtectedHeaderAlgorithm,
Exactly(CoseContentEncryptionAlgorithm),
ProtectedHeaderAlgorithmOrLegacyDefault(CoseContentEncryptionAlgorithm),
}Expand description
Policy for resolving and validating a COSE message’s content-encryption algorithm.
Variants
RequireProtectedHeaderAlgorithm
Require a supported algorithm in the protected header.
Exactly(CoseContentEncryptionAlgorithm)
Require the protected algorithm to exactly match the independently known CEK algorithm.
ProtectedHeaderAlgorithmOrLegacyDefault(CoseContentEncryptionAlgorithm)
Use the protected algorithm when present, or the supplied default for a legacy message.